@@ -27,7 +27,7 @@ class FlaskAppWrapper:
 
     @staticmethod
     def parse_proto_msg_to_json(
-        response, preserve_field_name=True, include_defaults=True
+            response, preserve_field_name=True, include_defaults=True
     ):
         return proto_json.MessageToJson(
             response,
@@ -36,6 +36,7 @@ class FlaskAppWrapper:
         )
 
     @staticmethod
+    @metrics.do_not_track()
     def ping():
         return "Success", status.HTTP_200_OK
 
@@ -53,8 +54,8 @@ class FlaskAppWrapper:
             if schema is not None:
                 # back to protobuf to json
                 _ = FlaskAppWrapper.parse_to_protobuf_msg(
-                        response, schema.Response()
-                    )
+                    response, schema.Response()
+                )
             response_status = status.HTTP_200_OK
         except proto_json.Error as e:
             response["error"] = str(e)
@@ -62,7 +63,7 @@ class FlaskAppWrapper:
             response_status = status.HTTP_400_BAD_REQUEST
         except InvalidRequest as e:
             response["error"] = str(e)
-            FlaskAppWrapper.logger.error(str(e))
+            FlaskAppWrapper.logger.warning(str(e))
             response_status = status.HTTP_400_BAD_REQUEST
         except KeyError as e:
             response["error"] = str(e)
